# Generated by Django 5.2.6 on 2025-09-30 00:38

import _socket
import django.core.validators
import django.db.models.deletion
import django.utils.timezone
import django_audit_fields.fields.hostname_modification_field
import django_audit_fields.fields.userfield
import django_audit_fields.fields.uuid_auto_field
import django_revision.revision_field
import edc_crf.model_mixins.crf_status_model_mixin
import edc_model.models.fields.initials_field
import edc_model.validators.date
import edc_model_fields.fields.other_charfield
import edc_protocol.validators
import edc_visit_tracking.managers
import simple_history.models
import uuid
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("meta_subject", "0230_alter_historicaldelivery_action_identifier_and_more"),
        ("sites", "0002_alter_domain_unique"),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalmedicationadherence",
            name="consent_model",
            field=models.CharField(blank=True, default="", max_length=50),
        ),
        migrations.AlterField(
            model_name="historicalmedicationadherence",
            name="consent_version",
            field=models.CharField(blank=True, default="", max_length=10),
        ),
        migrations.AlterField(
            model_name="historicalmedicationadherence",
            name="crf_status_comments",
            field=models.TextField(
                blank=True,
                default="",
                help_text="for example, why some data is still pending",
                verbose_name="Any comments related to status of this CRF",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmedicationadherence",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="historicalmedicationadherence",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="historicalmedicationadherence",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmedicationadherence",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmedicationadherence",
            name="pill_count_not_performed_reason",
            field=models.TextField(
                blank=True,
                default="",
                verbose_name="If not performed, please explain ...",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmedicationadherence",
            name="report_datetime",
            field=models.DateTimeField(
                default=django.utils.timezone.now,
                help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.",
                validators=[
                    edc_protocol.validators.datetime_not_before_study_start,
                    edc_model.validators.date.datetime_not_future,
                ],
                verbose_name="Report Date",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmedicationadherence",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmnsi",
            name="consent_model",
            field=models.CharField(blank=True, default="", max_length=50),
        ),
        migrations.AlterField(
            model_name="historicalmnsi",
            name="consent_version",
            field=models.CharField(blank=True, default="", max_length=10),
        ),
        migrations.AlterField(
            model_name="historicalmnsi",
            name="crf_status_comments",
            field=models.TextField(
                blank=True,
                default="",
                help_text="for example, why some data is still pending",
                verbose_name="Any comments related to status of this CRF",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmnsi",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="historicalmnsi",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="historicalmnsi",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmnsi",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmnsi",
            name="mnsi_not_performed_reason",
            field=models.TextField(
                blank=True,
                default="",
                max_length=200,
                verbose_name="If NO, please provide a reason",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmnsi",
            name="report_datetime",
            field=models.DateTimeField(
                default=django.utils.timezone.now,
                help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.",
                validators=[
                    edc_protocol.validators.datetime_not_before_study_start,
                    edc_model.validators.date.datetime_not_future,
                ],
                verbose_name="Report Date",
            ),
        ),
        migrations.AlterField(
            model_name="historicalmnsi",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="historicalnextappointment",
            name="consent_model",
            field=models.CharField(blank=True, default="", max_length=50),
        ),
        migrations.AlterField(
            model_name="historicalnextappointment",
            name="consent_version",
            field=models.CharField(blank=True, default="", max_length=10),
        ),
        migrations.AlterField(
            model_name="historicalnextappointment",
            name="crf_status_comments",
            field=models.TextField(
                blank=True,
                default="",
                help_text="for example, why some data is still pending",
                verbose_name="Any comments related to status of this CRF",
            ),
        ),
        migrations.AlterField(
            model_name="historicalnextappointment",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="historicalnextappointment",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="historicalnextappointment",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalnextappointment",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalnextappointment",
            name="report_datetime",
            field=models.DateTimeField(
                default=django.utils.timezone.now,
                help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.",
                validators=[
                    edc_protocol.validators.datetime_not_before_study_start,
                    edc_model.validators.date.datetime_not_future,
                ],
                verbose_name="Report Date",
            ),
        ),
        migrations.AlterField(
            model_name="historicalnextappointment",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="historicalotherarvregimens",
            name="consent_model",
            field=models.CharField(blank=True, default="", max_length=50),
        ),
        migrations.AlterField(
            model_name="historicalotherarvregimens",
            name="consent_version",
            field=models.CharField(blank=True, default="", max_length=10),
        ),
        migrations.AlterField(
            model_name="historicalotherarvregimens",
            name="crf_status_comments",
            field=models.TextField(
                blank=True,
                default="",
                help_text="for example, why some data is still pending",
                verbose_name="Any comments related to status of this CRF",
            ),
        ),
        migrations.AlterField(
            model_name="historicalotherarvregimens",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="historicalotherarvregimens",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="historicalotherarvregimens",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalotherarvregimens",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalotherarvregimens",
            name="report_datetime",
            field=models.DateTimeField(
                default=django.utils.timezone.now,
                help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.",
                validators=[
                    edc_protocol.validators.datetime_not_before_study_start,
                    edc_model.validators.date.datetime_not_future,
                ],
                verbose_name="Report Date",
            ),
        ),
        migrations.AlterField(
            model_name="historicalotherarvregimens",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="historicalotherarvregimensdetail",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="historicalotherarvregimensdetail",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="historicalotherarvregimensdetail",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalotherarvregimensdetail",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalotherarvregimensdetail",
            name="notes",
            field=models.CharField(
                blank=True, default="", max_length=100, verbose_name="Notes"
            ),
        ),
        migrations.AlterField(
            model_name="historicalotherarvregimensdetail",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="historicalpatienthistory",
            name="concomitant_conditions",
            field=models.TextField(
                blank=True,
                default="",
                max_length=250,
                verbose_name="Does the patient have any other conditions not mentioned above?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalpatienthistory",
            name="concomitant_medications",
            field=models.TextField(
                blank=True,
                default="",
                max_length=250,
                verbose_name="Is the patient taking any concomitant medications?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalpatienthistory",
            name="consent_model",
            field=models.CharField(blank=True, default="", max_length=50),
        ),
        migrations.AlterField(
            model_name="historicalpatienthistory",
            name="consent_version",
            field=models.CharField(blank=True, default="", max_length=10),
        ),
        migrations.AlterField(
            model_name="historicalpatienthistory",
            name="crf_status_comments",
            field=models.TextField(
                blank=True,
                default="",
                help_text="for example, why some data is still pending",
                verbose_name="Any comments related to status of this CRF",
            ),
        ),
        migrations.AlterField(
            model_name="historicalpatienthistory",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="historicalpatienthistory",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="historicalpatienthistory",
            name="dyslipidaemia_diagnosis",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="",
                max_length=15,
                verbose_name="Has the patient been diagnosed with dyslipidaemia?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalpatienthistory",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalpatienthistory",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalpatienthistory",
            name="other_dm_symptoms",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                default="",
                max_length=35,
                verbose_name="If other symptom in the <u>past year</u>, please specify ...",
            ),
        ),
        migrations.AlterField(
            model_name="historicalpatienthistory",
            name="other_dyslipidaemia_rx",
            field=models.CharField(
                blank=True,
                default="",
                max_length=50,
                verbose_name="What medication is the patient currently taking for dyslipidaemia?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalpatienthistory",
            name="report_datetime",
            field=models.DateTimeField(
                default=django.utils.timezone.now,
                help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.",
                validators=[
                    edc_protocol.validators.datetime_not_before_study_start,
                    edc_model.validators.date.datetime_not_future,
                ],
                verbose_name="Report Date",
            ),
        ),
        migrations.AlterField(
            model_name="historicalpatienthistory",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="historicalphysicalexam",
            name="abdominal_tenderness_description",
            field=models.TextField(
                blank=True,
                default="",
                verbose_name="If YES, abdominal tenderness, please describe",
            ),
        ),
        migrations.AlterField(
            model_name="historicalphysicalexam",
            name="consent_model",
            field=models.CharField(blank=True, default="", max_length=50),
        ),
        migrations.AlterField(
            model_name="historicalphysicalexam",
            name="consent_version",
            field=models.CharField(blank=True, default="", max_length=10),
        ),
        migrations.AlterField(
            model_name="historicalphysicalexam",
            name="crf_status_comments",
            field=models.TextField(
                blank=True,
                default="",
                help_text="for example, why some data is still pending",
                verbose_name="Any comments related to status of this CRF",
            ),
        ),
        migrations.AlterField(
            model_name="historicalphysicalexam",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="historicalphysicalexam",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="historicalphysicalexam",
            name="irregular_heartbeat_description",
            field=models.TextField(
                blank=True,
                default="",
                verbose_name="If the heartbeat is <u>irregular</u>, please describe",
            ),
        ),
        migrations.AlterField(
            model_name="historicalphysicalexam",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalphysicalexam",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalphysicalexam",
            name="report_datetime",
            field=models.DateTimeField(
                default=django.utils.timezone.now,
                help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.",
                validators=[
                    edc_protocol.validators.datetime_not_before_study_start,
                    edc_model.validators.date.datetime_not_future,
                ],
                verbose_name="Report Date",
            ),
        ),
        migrations.AlterField(
            model_name="historicalphysicalexam",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="historicalphysicalexam",
            name="severe_htn",
            field=models.CharField(
                blank=True,
                choices=[("Yes", "Yes"), ("No", "No")],
                default="",
                help_text="Based on the above readings. Severe HTN is any BP reading > 180/110mmHg",
                max_length=15,
                verbose_name="Does the patient have severe hypertension?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalphysicalexam",
            name="waist_circumference_comment",
            field=models.TextField(
                blank=True,
                default="",
                help_text="A reason not measured may be provided at anytime but is required at 36 and 48 months",
                verbose_name="If waist circumference not measured, please explain ...",
            ),
        ),
        migrations.AlterField(
            model_name="historicalpregnancyupdate",
            name="comment",
            field=models.TextField(default="", verbose_name="Comment / Updates"),
        ),
        migrations.AlterField(
            model_name="historicalpregnancyupdate",
            name="consent_model",
            field=models.CharField(blank=True, default="", max_length=50),
        ),
        migrations.AlterField(
            model_name="historicalpregnancyupdate",
            name="consent_version",
            field=models.CharField(blank=True, default="", max_length=10),
        ),
        migrations.AlterField(
            model_name="historicalpregnancyupdate",
            name="crf_status_comments",
            field=models.TextField(
                blank=True,
                default="",
                help_text="for example, why some data is still pending",
                verbose_name="Any comments related to status of this CRF",
            ),
        ),
        migrations.AlterField(
            model_name="historicalpregnancyupdate",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="historicalpregnancyupdate",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="historicalpregnancyupdate",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalpregnancyupdate",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalpregnancyupdate",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsf12",
            name="consent_model",
            field=models.CharField(blank=True, default="", max_length=50),
        ),
        migrations.AlterField(
            model_name="historicalsf12",
            name="consent_version",
            field=models.CharField(blank=True, default="", max_length=10),
        ),
        migrations.AlterField(
            model_name="historicalsf12",
            name="crf_status_comments",
            field=models.TextField(
                blank=True,
                default="",
                help_text="for example, why some data is still pending",
                verbose_name="Any comments related to status of this CRF",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsf12",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="historicalsf12",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="historicalsf12",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsf12",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsf12",
            name="report_datetime",
            field=models.DateTimeField(
                default=django.utils.timezone.now,
                help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.",
                validators=[
                    edc_protocol.validators.datetime_not_before_study_start,
                    edc_model.validators.date.datetime_not_future,
                ],
                verbose_name="Report Date",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsf12",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="historicalstudymedication",
            name="consent_model",
            field=models.CharField(blank=True, default="", max_length=50),
        ),
        migrations.AlterField(
            model_name="historicalstudymedication",
            name="consent_version",
            field=models.CharField(blank=True, default="", max_length=10),
        ),
        migrations.AlterField(
            model_name="historicalstudymedication",
            name="crf_status_comments",
            field=models.TextField(
                blank=True,
                default="",
                help_text="for example, why some data is still pending",
                verbose_name="Any comments related to status of this CRF",
            ),
        ),
        migrations.AlterField(
            model_name="historicalstudymedication",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="historicalstudymedication",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="historicalstudymedication",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalstudymedication",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalstudymedication",
            name="report_datetime",
            field=models.DateTimeField(
                default=django.utils.timezone.now,
                help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.",
                validators=[
                    edc_protocol.validators.datetime_not_before_study_start,
                    edc_model.validators.date.datetime_not_future,
                ],
                verbose_name="Report Date",
            ),
        ),
        migrations.AlterField(
            model_name="historicalstudymedication",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="historicalstudymedication",
            name="special_instructions",
            field=models.TextField(blank=True, default=""),
        ),
        migrations.AlterField(
            model_name="historicalstudymedication",
            name="stock_codes",
            field=models.TextField(
                blank=True,
                default="",
                help_text="Enter the medication bottle barcode or barcodes. Type one code per line",
                max_length=30,
                validators=[
                    django.core.validators.RegexValidator(
                        message="Enter one or more valid codes, one code per line",
                        regex="^([A-Z0-9]{6})(\r\n[A-Z0-9]{6})*$",
                    )
                ],
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectrequisition",
            name="clinic_verified",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")], default="", max_length=15
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectrequisition",
            name="clinician_initials",
            field=edc_model.models.fields.initials_field.InitialsField(
                blank=True,
                default="",
                help_text="Type 2-3 letters, all in uppercase and no spaces",
                max_length=3,
                verbose_name="Initials",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectrequisition",
            name="comments",
            field=models.TextField(blank=True, default="", max_length=25),
        ),
        migrations.AlterField(
            model_name="historicalsubjectrequisition",
            name="consent_model",
            field=models.CharField(blank=True, default="", max_length=50),
        ),
        migrations.AlterField(
            model_name="historicalsubjectrequisition",
            name="consent_version",
            field=models.CharField(blank=True, default="", max_length=10),
        ),
        migrations.AlterField(
            model_name="historicalsubjectrequisition",
            name="crf_status_comments",
            field=models.TextField(
                blank=True,
                default="",
                help_text="for example, why some data is still pending",
                verbose_name="Any comments related to status of this CRF",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectrequisition",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectrequisition",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectrequisition",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectrequisition",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectrequisition",
            name="protocol_number",
            field=models.CharField(default="", editable=False, max_length=10),
        ),
        migrations.AlterField(
            model_name="historicalsubjectrequisition",
            name="report_datetime",
            field=models.DateTimeField(
                default=django.utils.timezone.now,
                help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.",
                validators=[
                    edc_protocol.validators.datetime_not_before_study_start,
                    edc_model.validators.date.datetime_not_future,
                ],
                verbose_name="Report Date",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectrequisition",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectrequisition",
            name="slug",
            field=models.CharField(
                db_index=True,
                default="",
                editable=False,
                help_text="Hold slug field values for quick search. Excludes encrypted fields",
                max_length=250,
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectrequisition",
            name="specimen_type",
            field=models.CharField(
                blank=True, default="", max_length=25, verbose_name="Specimen type"
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisit",
            name="comments",
            field=models.TextField(
                blank=True,
                default="",
                max_length=250,
                verbose_name="Comment if any additional pertinent information about the participant",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisit",
            name="consent_model",
            field=models.CharField(blank=True, default="", max_length=50),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisit",
            name="consent_version",
            field=models.CharField(blank=True, default="", max_length=10),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisit",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisit",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisit",
            name="document_status_comments",
            field=models.TextField(
                blank=True,
                default="",
                help_text="for example, why some data is still pending",
                verbose_name="Any comments related to status of this document",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisit",
            name="info_source_other",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                default="",
                max_length=35,
                verbose_name='If "Other" source of information, specify',
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisit",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisit",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisit",
            name="reason_missed",
            field=models.CharField(
                blank=True,
                default="",
                max_length=35,
                verbose_name="If 'missed', provide the reason for the missed visit",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisit",
            name="reason_missed_other",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                default="",
                max_length=25,
                verbose_name='If the reason for the missed visit is "other", specify',
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisit",
            name="report_datetime",
            field=models.DateTimeField(
                default=django.utils.timezone.now,
                help_text="Date and time of this report",
                validators=[
                    edc_protocol.validators.datetime_not_before_study_start,
                    edc_model.validators.date.datetime_not_future,
                ],
                verbose_name="Report date and time",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisit",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisit",
            name="study_status",
            field=models.CharField(
                default="",
                max_length=50,
                verbose_name="What is the participant's current study status",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisit",
            name="survival_status",
            field=models.CharField(
                choices=[
                    ("alive", "Alive"),
                    ("dead", "Deceased"),
                    ("unknown", "Unknown"),
                    ("N/A", "Not applicable (if missed)"),
                ],
                default="alive",
                help_text="If YES, submit Death report",
                max_length=10,
                verbose_name="Participant's survival status",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisit",
            name="unschedule_detail",
            field=models.TextField(
                blank=True,
                default="",
                verbose_name="If 'unschedule', please provide further details, if any",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisit",
            name="visit_code",
            field=models.CharField(default="", editable=False, max_length=25),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisitmissed",
            name="action_identifier",
            field=models.CharField(blank=True, db_index=True, default="", max_length=50),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisitmissed",
            name="action_item_reason",
            field=models.TextField(default="", editable=False),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisitmissed",
            name="comment",
            field=models.TextField(
                blank=True,
                default="",
                verbose_name="Please provide further details, if any",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisitmissed",
            name="consent_model",
            field=models.CharField(blank=True, default="", max_length=50),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisitmissed",
            name="consent_version",
            field=models.CharField(blank=True, default="", max_length=10),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisitmissed",
            name="contact_attempts_explained",
            field=models.TextField(
                blank=True,
                default="",
                verbose_name="If contact not made and less than 3 attempts, please explain",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisitmissed",
            name="crf_status_comments",
            field=models.TextField(
                blank=True,
                default="",
                help_text="for example, why some data is still pending",
                verbose_name="Any comments related to status of this CRF",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisitmissed",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisitmissed",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisitmissed",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisitmissed",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisitmissed",
            name="parent_action_identifier",
            field=models.CharField(
                blank=True,
                default="",
                help_text="action identifier that links to parent reference model instance.",
                max_length=30,
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisitmissed",
            name="related_action_identifier",
            field=models.CharField(
                blank=True,
                default="",
                help_text="action identifier that links to related reference model instance.",
                max_length=30,
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisitmissed",
            name="report_datetime",
            field=models.DateTimeField(
                default=django.utils.timezone.now,
                help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.",
                validators=[
                    edc_protocol.validators.datetime_not_before_study_start,
                    edc_model.validators.date.datetime_not_future,
                ],
                verbose_name="Report Date",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisitmissed",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="historicalurinedipsticktest",
            name="consent_model",
            field=models.CharField(blank=True, default="", max_length=50),
        ),
        migrations.AlterField(
            model_name="historicalurinedipsticktest",
            name="consent_version",
            field=models.CharField(blank=True, default="", max_length=10),
        ),
        migrations.AlterField(
            model_name="historicalurinedipsticktest",
            name="crf_status_comments",
            field=models.TextField(
                blank=True,
                default="",
                help_text="for example, why some data is still pending",
                verbose_name="Any comments related to status of this CRF",
            ),
        ),
        migrations.AlterField(
            model_name="historicalurinedipsticktest",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="historicalurinedipsticktest",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="historicalurinedipsticktest",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalurinedipsticktest",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalurinedipsticktest",
            name="not_performed_reason",
            field=models.CharField(
                blank=True,
                default="",
                max_length=150,
                verbose_name="If NO, provide reason",
            ),
        ),
        migrations.AlterField(
            model_name="historicalurinedipsticktest",
            name="report_datetime",
            field=models.DateTimeField(
                default=django.utils.timezone.now,
                help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.",
                validators=[
                    edc_protocol.validators.datetime_not_before_study_start,
                    edc_model.validators.date.datetime_not_future,
                ],
                verbose_name="Report Date",
            ),
        ),
        migrations.AlterField(
            model_name="historicalurinedipsticktest",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="historicalurinepregnancy",
            name="action_identifier",
            field=models.CharField(blank=True, db_index=True, default="", max_length=50),
        ),
        migrations.AlterField(
            model_name="historicalurinepregnancy",
            name="action_item_reason",
            field=models.TextField(default="", editable=False),
        ),
        migrations.AlterField(
            model_name="historicalurinepregnancy",
            name="consent_model",
            field=models.CharField(blank=True, default="", max_length=50),
        ),
        migrations.AlterField(
            model_name="historicalurinepregnancy",
            name="consent_version",
            field=models.CharField(blank=True, default="", max_length=10),
        ),
        migrations.AlterField(
            model_name="historicalurinepregnancy",
            name="crf_status_comments",
            field=models.TextField(
                blank=True,
                default="",
                help_text="for example, why some data is still pending",
                verbose_name="Any comments related to status of this CRF",
            ),
        ),
        migrations.AlterField(
            model_name="historicalurinepregnancy",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="historicalurinepregnancy",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="historicalurinepregnancy",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalurinepregnancy",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalurinepregnancy",
            name="not_performed_reason",
            field=models.CharField(
                blank=True,
                default="",
                max_length=150,
                verbose_name="If NO, provide reason",
            ),
        ),
        migrations.AlterField(
            model_name="historicalurinepregnancy",
            name="parent_action_identifier",
            field=models.CharField(
                blank=True,
                default="",
                help_text="action identifier that links to parent reference model instance.",
                max_length=30,
            ),
        ),
        migrations.AlterField(
            model_name="historicalurinepregnancy",
            name="related_action_identifier",
            field=models.CharField(
                blank=True,
                default="",
                help_text="action identifier that links to related reference model instance.",
                max_length=30,
            ),
        ),
        migrations.AlterField(
            model_name="historicalurinepregnancy",
            name="report_datetime",
            field=models.DateTimeField(
                default=django.utils.timezone.now,
                help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.",
                validators=[
                    edc_protocol.validators.datetime_not_before_study_start,
                    edc_model.validators.date.datetime_not_future,
                ],
                verbose_name="Report Date",
            ),
        ),
        migrations.AlterField(
            model_name="historicalurinepregnancy",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="malariatest",
            name="consent_model",
            field=models.CharField(blank=True, default="", max_length=50),
        ),
        migrations.AlterField(
            model_name="malariatest",
            name="consent_version",
            field=models.CharField(blank=True, default="", max_length=10),
        ),
        migrations.AlterField(
            model_name="malariatest",
            name="crf_status_comments",
            field=models.TextField(
                blank=True,
                default="",
                help_text="for example, why some data is still pending",
                verbose_name="Any comments related to status of this CRF",
            ),
        ),
        migrations.AlterField(
            model_name="malariatest",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="malariatest",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="malariatest",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="malariatest",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="malariatest",
            name="not_performed_reason",
            field=models.CharField(
                blank=True,
                default="",
                max_length=150,
                verbose_name="If NO, provide reason",
            ),
        ),
        migrations.AlterField(
            model_name="malariatest",
            name="report_datetime",
            field=models.DateTimeField(
                default=django.utils.timezone.now,
                help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.",
                validators=[
                    edc_protocol.validators.datetime_not_before_study_start,
                    edc_model.validators.date.datetime_not_future,
                ],
                verbose_name="Report Date",
            ),
        ),
        migrations.AlterField(
            model_name="malariatest",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="medicationadherence",
            name="consent_model",
            field=models.CharField(blank=True, default="", max_length=50),
        ),
        migrations.AlterField(
            model_name="medicationadherence",
            name="consent_version",
            field=models.CharField(blank=True, default="", max_length=10),
        ),
        migrations.AlterField(
            model_name="medicationadherence",
            name="crf_status_comments",
            field=models.TextField(
                blank=True,
                default="",
                help_text="for example, why some data is still pending",
                verbose_name="Any comments related to status of this CRF",
            ),
        ),
        migrations.AlterField(
            model_name="medicationadherence",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="medicationadherence",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="medicationadherence",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="medicationadherence",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="medicationadherence",
            name="pill_count_not_performed_reason",
            field=models.TextField(
                blank=True,
                default="",
                verbose_name="If not performed, please explain ...",
            ),
        ),
        migrations.AlterField(
            model_name="medicationadherence",
            name="report_datetime",
            field=models.DateTimeField(
                default=django.utils.timezone.now,
                help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.",
                validators=[
                    edc_protocol.validators.datetime_not_before_study_start,
                    edc_model.validators.date.datetime_not_future,
                ],
                verbose_name="Report Date",
            ),
        ),
        migrations.AlterField(
            model_name="medicationadherence",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="mnsi",
            name="consent_model",
            field=models.CharField(blank=True, default="", max_length=50),
        ),
        migrations.AlterField(
            model_name="mnsi",
            name="consent_version",
            field=models.CharField(blank=True, default="", max_length=10),
        ),
        migrations.AlterField(
            model_name="mnsi",
            name="crf_status_comments",
            field=models.TextField(
                blank=True,
                default="",
                help_text="for example, why some data is still pending",
                verbose_name="Any comments related to status of this CRF",
            ),
        ),
        migrations.AlterField(
            model_name="mnsi",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="mnsi",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="mnsi",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="mnsi",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="mnsi",
            name="mnsi_not_performed_reason",
            field=models.TextField(
                blank=True,
                default="",
                max_length=200,
                verbose_name="If NO, please provide a reason",
            ),
        ),
        migrations.AlterField(
            model_name="mnsi",
            name="report_datetime",
            field=models.DateTimeField(
                default=django.utils.timezone.now,
                help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.",
                validators=[
                    edc_protocol.validators.datetime_not_before_study_start,
                    edc_model.validators.date.datetime_not_future,
                ],
                verbose_name="Report Date",
            ),
        ),
        migrations.AlterField(
            model_name="mnsi",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="nextappointment",
            name="consent_model",
            field=models.CharField(blank=True, default="", max_length=50),
        ),
        migrations.AlterField(
            model_name="nextappointment",
            name="consent_version",
            field=models.CharField(blank=True, default="", max_length=10),
        ),
        migrations.AlterField(
            model_name="nextappointment",
            name="crf_status_comments",
            field=models.TextField(
                blank=True,
                default="",
                help_text="for example, why some data is still pending",
                verbose_name="Any comments related to status of this CRF",
            ),
        ),
        migrations.AlterField(
            model_name="nextappointment",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="nextappointment",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="nextappointment",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="nextappointment",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="nextappointment",
            name="report_datetime",
            field=models.DateTimeField(
                default=django.utils.timezone.now,
                help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.",
                validators=[
                    edc_protocol.validators.datetime_not_before_study_start,
                    edc_model.validators.date.datetime_not_future,
                ],
                verbose_name="Report Date",
            ),
        ),
        migrations.AlterField(
            model_name="nextappointment",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="otherarvregimens",
            name="consent_model",
            field=models.CharField(blank=True, default="", max_length=50),
        ),
        migrations.AlterField(
            model_name="otherarvregimens",
            name="consent_version",
            field=models.CharField(blank=True, default="", max_length=10),
        ),
        migrations.AlterField(
            model_name="otherarvregimens",
            name="crf_status_comments",
            field=models.TextField(
                blank=True,
                default="",
                help_text="for example, why some data is still pending",
                verbose_name="Any comments related to status of this CRF",
            ),
        ),
        migrations.AlterField(
            model_name="otherarvregimens",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="otherarvregimens",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="otherarvregimens",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="otherarvregimens",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="otherarvregimens",
            name="report_datetime",
            field=models.DateTimeField(
                default=django.utils.timezone.now,
                help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.",
                validators=[
                    edc_protocol.validators.datetime_not_before_study_start,
                    edc_model.validators.date.datetime_not_future,
                ],
                verbose_name="Report Date",
            ),
        ),
        migrations.AlterField(
            model_name="otherarvregimens",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="otherarvregimensdetail",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="otherarvregimensdetail",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="otherarvregimensdetail",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="otherarvregimensdetail",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="otherarvregimensdetail",
            name="notes",
            field=models.CharField(
                blank=True, default="", max_length=100, verbose_name="Notes"
            ),
        ),
        migrations.AlterField(
            model_name="otherarvregimensdetail",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
    ]



from .birth_outcomes import BirthOutcomes
from .blood_results import (
    BloodResultsFbc,
    BloodResultsGluDummy,
    BloodResultsHba1c,
    BloodResultsIns,
    BloodResultsLft,
    BloodResultsLipids,
    BloodResultsRft,
)
from .complications import Complications
from .complications_glycemia import ComplicationsGlycemia
from .concomitant_medication import ConcomitantMedication
from .delivery import Delivery
from .diabetes import DmEndpoint, DmFollowup
from .diet_and_lifestyle import DietAndLifestyle
from .egfr_drop_notification import EgfrDropNotification
from .eq5d3l import Eq5d3l
from .followup_examination import FollowupExamination
from .followup_vitals import FollowupVitals
from .glucose import Glucose
from .glucose_fbg import GlucoseFbg
from .health_economics import (
    HealthEconomics,
    HealthEconomicsSimple,
    HealthEconomicsUpdate,
)
from .hepatitis_test import HepatitisTest
from .hiv_exit_review import HivExitReview
from .malaria_test import MalariaTest
from .medication_adherence import MedicationAdherence
from .mnsi import Mnsi
from .next_appointment import NextAppointment
from .other_arv_regimens import OtherArvRegimens
from .other_arv_regimens_detail import OtherArvRegimensDetail
from .patient_history import PatientHistory
from .physical_exam import PhysicalExam
from .pregnancy_update import PregnancyUpdate
from .sf12 import Sf12
from .signals import (
    study_medication_on_pre_save,
    update_glucose_endpoints_for_subject_on_post_save,
    update_pregnancy_notification_on_delivery_post_save,
    update_schedule_on_delivery_post_save,
)
from .study_medication import StudyMedication
from .subject_requisition import SubjectRequisition
from .subject_visit import SubjectVisit
from .subject_visit_missed import SubjectVisitMissed
from .urine_dipstick_test import UrineDipstickTest
from .urine_pregnancy import UrinePregnancy

__all__ = [
    "BirthOutcomes",
    "BloodResultsFbc",
    "BloodResultsGluDummy",
    "BloodResultsHba1c",
    "BloodResultsIns",
    "BloodResultsLft",
    "BloodResultsLipids",
    "BloodResultsRft",
    "Complications",
    "ComplicationsGlycemia",
    "ConcomitantMedication",
    "Delivery",
    "DietAndLifestyle",
    "DmEndpoint",
    "DmFollowup",
    "EgfrDropNotification",
    "Eq5d3l",
    "FollowupExamination",
    "FollowupVitals",
    "Glucose",
    "GlucoseFbg",
    "HealthEconomics",
    "HealthEconomicsSimple",
    "HealthEconomicsUpdate",
    "HepatitisTest",
    "HivExitReview",
    "MalariaTest",
    "MedicationAdherence",
    "Mnsi",
    "NextAppointment",
    "OtherArvRegimens",
    "OtherArvRegimensDetail",
    "PatientHistory",
    "PhysicalExam",
    "PregnancyUpdate",
    "Sf12",
    "StudyMedication",
    "SubjectRequisition",
    "SubjectVisit",
    "SubjectVisitMissed",
    "UrineDipstickTest",
    "UrinePregnancy",
    "study_medication_on_pre_save",
    "update_glucose_endpoints_for_subject_on_post_save",
    "update_pregnancy_notification_on_delivery_post_save",
    "update_schedule_on_delivery_post_save",
]



# Generated by Django 4.0.5 on 2022-06-30 08:10
from django.core.exceptions import ObjectDoesNotExist
from django.db import migrations
from django.db.models.signals import post_save, pre_save
from clinicedc_constants import HIGH
from edc_protocol_incident.constants import PROTOCOL_INCIDENT_ACTION
from edc_utils import DisableSignals

from meta_prn.constants import PROTOCOL_DEVIATION_VIOLATION_ACTION


def update_for_protocol_incident(apps, schema_editor):
    action_item_model_cls = apps.get_model("edc_action_item.actionitem")
    action_type_model_cls = apps.get_model("edc_action_item.actiontype")
    crf_metadata_model_cls = apps.get_model("edc_metadata.crfmetadata")

    with DisableSignals(disabled_signals=[pre_save, post_save]):
        # update crf metadata if there is any
        crf_metadata_model_cls.objects.filter(
            model="meta_prn.protocoldeviationviolation"
        ).update(model="meta_prn.protocolincident")

        # update action type
        try:
            action_type = action_type_model_cls.objects.get(name=PROTOCOL_INCIDENT_ACTION)
        except ObjectDoesNotExist:
            action_type = action_type_model_cls.objects.create(
                name=PROTOCOL_INCIDENT_ACTION,
                display_name=PROTOCOL_INCIDENT_ACTION,
                reference_model="meta_prn.protocolincident",
                priority=HIGH,
                show_on_dashboard=True,
                show_link_to_changelist=True,
            )
        action_item_model_cls.objects.filter(
            action_type__name=PROTOCOL_DEVIATION_VIOLATION_ACTION
        ).update(action_type=action_type)

        # update crf metadata if there is any
        # action_item_model_cls.objects.filter(
        #     reference_model="meta_prn.protocoldeviationviolation"
        # ).update(reference_model="meta_prn.protocolincident")


class Migration(migrations.Migration):
    dependencies = [
        ("meta_prn", "0033_remove_historicalegfrnotification_action_item_and_more"),
    ]

    operations = [migrations.RunPython(update_for_protocol_incident)]



from django.contrib import admin
from django_audit_fields.admin import audit_fieldset_tuple
from edc_model_admin.history import SimpleHistoryAdmin
from edc_sites.admin import SiteModelAdminMixin
from edc_visit_schedule.fieldsets import visit_schedule_fieldset_tuple
from edc_visit_tracking.modeladmin_mixins import VisitModelAdminMixin

from ..admin_site import meta_subject_admin
from ..forms import SubjectVisitForm
from ..models import SubjectVisit
from .modeladmin import ModelAdminMixin


@admin.register(SubjectVisit, site=meta_subject_admin)
class SubjectVisitAdmin(
    VisitModelAdminMixin, SiteModelAdminMixin, ModelAdminMixin, SimpleHistoryAdmin
):
    show_dashboard_in_list_display_pos = 2

    form = SubjectVisitForm

    fieldsets = (
        (
            None,
            {
                "fields": [
                    "appointment",
                    "report_datetime",
                    "reason",
                    "reason_unscheduled",
                    "reason_unscheduled_other",
                    "info_source",
                    "info_source_other",
                    "comments",
                ]
            },
        ),
        visit_schedule_fieldset_tuple,
        audit_fieldset_tuple,
    )

    radio_fields = {  # noqa: RUF012
        "reason": admin.VERTICAL,
        "reason_unscheduled": admin.VERTICAL,
        "info_source": admin.VERTICAL,
    }



from django.db import models
from edc_action_item.models import ActionModelMixin
from edc_consent.field_mixins import ReviewFieldsMixin
from edc_consent.model_mixins import ConsentExtensionModelMixin
from edc_model.models import BaseUuidModel
from edc_sites.model_mixins import SiteModelMixin

from ..constants import CONSENT_V1_EXTENSION_ACTION
from .subject_consent_v1 import SubjectConsentV1


class SubjectConsentV1Ext(
    ConsentExtensionModelMixin,
    SiteModelMixin,
    ActionModelMixin,
    ReviewFieldsMixin,
    BaseUuidModel,
):
    """A consent extension to allow a participant to extend followup
    up to 48 months, or not.
    """

    subject_consent = models.ForeignKey(SubjectConsentV1, on_delete=models.PROTECT)

    action_name = CONSENT_V1_EXTENSION_ACTION

    class Meta(
        ConsentExtensionModelMixin.Meta,
        SiteModelMixin.Meta,
        ActionModelMixin.Meta,
        BaseUuidModel.Meta,
    ):
        verbose_name = "Consent V1 Extension"
        verbose_name_plural = "Consent V1 Extension"



# Generated by Django 6.0 on 2025-04-22 19:14

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("meta_reports", "0054_auto_20250422_2003"),
    ]

    operations = [
        migrations.AlterModelTable(
            name="glucosesummary",
            table="meta_reports_glucosesummaryview",
        ),
    ]



from edc_crf.model_mixins import CrfStatusModelMixin
from edc_crf.model_mixins import CrfWithActionModelMixin as BaseCrfWithActionModelMixin


class CrfWithActionModelMixin(CrfStatusModelMixin, BaseCrfWithActionModelMixin):
    class Meta(BaseCrfWithActionModelMixin.Meta):
        abstract = True



from clinicedc_constants import PENDING, YES
from edc_crf.crf_form_validator import CrfFormValidator
from edc_glucose.form_validators import FbgOgttFormValidatorMixin

from ..constants import AMENDMENT_DATE
from .mixins import EndpointValidatorMixin, RepeatFbgDateValidatorMixin


class GlucoseFormValidator(
    EndpointValidatorMixin,
    RepeatFbgDateValidatorMixin,
    FbgOgttFormValidatorMixin,
    CrfFormValidator,
):
    def clean(self):
        self.required_if(YES, field="fasting", field_required="fasting_duration_str")
        self.validate_glucose_testing_matrix(include_fbg=True)
        has_results = (
            self.cleaned_data.get("fbg_value") is not None
            and self.cleaned_data.get("ogtt_value") is not None
            and self.cleaned_data.get("report_datetime").date() >= AMENDMENT_DATE
        )
        self.applicable_if_true(has_results, field_applicable="endpoint_today")
        if has_results:
            self.validate_endpoint_fields(
                performed=bool(
                    self.cleaned_data.get("fbg_value") is not None
                    or self.cleaned_data.get("ogtt_value") is not None
                )
            )
        self.required_if(PENDING, field="endpoint_today", field_required="repeat_fbg_date")
        self.validate_repeat_fbg_date()



from clinicedc_constants import TBD
from django.db import models
from edc_constants.choices import YES_NO_TBD
from edc_screening.model_mixins import (
    EligibilityModelMixin as BaseEligibilityModelMixin,
)

from ..eligibility import MetaEligibility


class EligibilityModelMixin(BaseEligibilityModelMixin):
    eligibility_cls = MetaEligibility

    eligible_part_one = models.CharField(
        max_length=15,
        choices=YES_NO_TBD,
        default=TBD,
        editable=False,
        help_text="system calculated value",
    )

    reasons_ineligible_part_one = models.TextField(max_length=150, default="", editable=False)

    eligible_part_two = models.CharField(
        max_length=15,
        choices=YES_NO_TBD,
        default=TBD,
        editable=False,
        help_text="system calculated value",
    )

    reasons_ineligible_part_two = models.TextField(max_length=150, default="", editable=False)

    eligible_part_three = models.CharField(
        max_length=15,
        choices=YES_NO_TBD,
        default=TBD,
        editable=False,
        help_text="system calculated value",
    )

    reasons_ineligible_part_three = models.TextField(
        max_length=150, default="", editable=False
    )

    def get_report_datetime_for_eligibility_datetime(self):
        return self.part_three_report_datetime

    class Meta:
        abstract = True



# Generated by Django 4.2.11 on 2024-05-15 23:20

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_subject", "0191_alter_dmdiagnosis_dx_no_tmg_reason_and_more"),
    ]

    operations = [
        migrations.RenameField(
            model_name="glucosefbg",
            old_name="glucose_quantifier",
            new_name="fbg_quantifier",
        ),
        migrations.RenameField(
            model_name="glucosefbg",
            old_name="glucose_units",
            new_name="fbg_units",
        ),
        migrations.RenameField(
            model_name="historicalglucosefbg",
            old_name="glucose_quantifier",
            new_name="fbg_quantifier",
        ),
        migrations.RenameField(
            model_name="historicalglucosefbg",
            old_name="glucose_units",
            new_name="fbg_units",
        ),
        migrations.RenameField(
            model_name="glucosefbg",
            old_name="glucose_value",
            new_name="fbg_value",
        ),
        migrations.RenameField(
            model_name="historicalglucosefbg",
            old_name="glucose_value",
            new_name="fbg_value",
        ),
    ]



from clinicedc_constants import NO, YES
from django import forms
from edc_crf.crf_form_validator import CrfFormValidator
from edc_crf.modelform_mixins import CrfModelFormMixin

from ..models import UrineDipstickTest


class UrineDipstickTestFormValidator(CrfFormValidator):
    def clean(self):
        self.required_if(NO, field="performed", field_required="not_performed_reason")

        self.applicable_if(YES, field="performed", field_applicable="ketones")

        self.applicable_if(YES, field="performed", field_applicable="protein")

        self.applicable_if(YES, field="performed", field_applicable="glucose")


class UrineDipstickTestForm(CrfModelFormMixin, forms.ModelForm):
    form_validator_cls = UrineDipstickTestFormValidator

    class Meta:
        model = UrineDipstickTest
        fields = "__all__"



from clinicedc_constants import COPIES_PER_MILLILITER, NULL_STRING
from django.core.validators import MaxValueValidator, MinValueValidator
from django.db import models
from edc_model.models import OtherCharField
from edc_reportable.units import CELLS_PER_MILLIMETER_CUBED_DISPLAY

from meta_lists.models import ArvRegimens


class ArvReviewModelMixin(models.Model):
    viral_load = models.IntegerField(
        verbose_name="Last viral load",
        validators=[MinValueValidator(0), MaxValueValidator(999999)],
        null=True,
        blank=True,
        help_text=COPIES_PER_MILLILITER,
    )

    viral_load_date = models.DateField(
        verbose_name="Date of last viral load", null=True, blank=True
    )

    cd4 = models.IntegerField(
        verbose_name="Last CD4",
        validators=[MinValueValidator(0), MaxValueValidator(3000)],
        null=True,
        blank=True,
        help_text=CELLS_PER_MILLIMETER_CUBED_DISPLAY,
    )

    cd4_date = models.DateField(verbose_name="Date of last CD4", null=True, blank=True)

    current_arv_regimen = models.ForeignKey(
        ArvRegimens,
        on_delete=models.PROTECT,
        related_name="current_arv_regimen",
        verbose_name="Which antiretroviral therapy regimen is the patient currently on?",
        null=True,
        blank=False,
    )

    other_current_arv_regimen = OtherCharField(default=NULL_STRING, blank=True)

    current_arv_regimen_start_date = models.DateField(
        verbose_name=(
            "When did the patient start this current antiretroviral therapy regimen?"
        ),
        null=True,
        blank=True,
    )

    class Meta:
        abstract = True



# Generated by Django 4.2.11 on 2024-05-15 17:42

import uuid

import _socket
import django.db.models.deletion
import django_audit_fields.fields.hostname_modification_field
import django_audit_fields.fields.userfield
import django_audit_fields.fields.uuid_auto_field
import django.utils.timezone
import django_revision.revision_field
import edc_crf.model_mixins.crf_status_model_mixin
import edc_model.validators.date
import edc_protocol.validators
import edc_utils.date
import edc_visit_tracking.managers
import simple_history.models
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ("sites", "0002_alter_domain_unique"),
        ("meta_subject", "0186_healtheconomicsupdate_singleton_field_and_more"),
    ]

    operations = [
        migrations.CreateModel(
            name="DmDiagnosis",
            fields=[
                (
                    "revision",
                    django_revision.revision_field.RevisionField(
                        blank=True,
                        editable=False,
                        help_text="System field. Git repository tag:branch:commit.",
                        max_length=75,
                        null=True,
                        verbose_name="Revision",
                    ),
                ),
                (
                    "created",
                    models.DateTimeField(blank=True, default=django.utils.timezone.now),
                ),
                (
                    "modified",
                    models.DateTimeField(blank=True, default=django.utils.timezone.now),
                ),
                (
                    "user_created",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user created",
                    ),
                ),
                (
                    "user_modified",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user modified",
                    ),
                ),
                (
                    "hostname_created",
                    models.CharField(
                        blank=True,
                        default=_socket.gethostname,
                        help_text="System field. (modified on create only)",
                        max_length=60,
                        verbose_name="Hostname created",
                    ),
                ),
                (
                    "hostname_modified",
                    django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                        blank=True,
                        help_text="System field. (modified on every save)",
                        max_length=50,
                        verbose_name="Hostname modified",
                    ),
                ),
                (
                    "device_created",
                    models.CharField(blank=True, max_length=10, verbose_name="Device created"),
                ),
                (
                    "device_modified",
                    models.CharField(
                        blank=True, max_length=10, verbose_name="Device modified"
                    ),
                ),
                (
                    "locale_created",
                    models.CharField(
                        blank=True,
                        help_text="Auto-updated by Modeladmin",
                        max_length=10,
                        null=True,
                        verbose_name="Locale created",
                    ),
                ),
                (
                    "locale_modified",
                    models.CharField(
                        blank=True,
                        help_text="Auto-updated by Modeladmin",
                        max_length=10,
                        null=True,
                        verbose_name="Locale modified",
                    ),
                ),
                (
                    "id",
                    django_audit_fields.fields.uuid_auto_field.UUIDAutoField(
                        blank=True,
                        editable=False,
                        help_text="System auto field. UUID primary key.",
                        primary_key=True,
                        serialize=False,
                    ),
                ),
                ("consent_model", models.CharField(blank=True, max_length=50, null=True)),
                ("consent_version", models.CharField(blank=True, max_length=10, null=True)),
                (
                    "report_datetime",
                    models.DateTimeField(
                        default=edc_utils.date.get_utcnow,
                        help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.",
                        validators=[
                            edc_protocol.validators.datetime_not_before_study_start,
                            edc_model.validators.date.datetime_not_future,
                        ],
                        verbose_name="Report Date",
                    ),
                ),
                (
                    "crf_status",
                    models.CharField(
                        choices=[
                            ("INCOMPLETE", "Incomplete (some data pending)"),
                            ("COMPLETE", "Complete"),
                        ],
                        default=edc_crf.model_mixins.crf_status_model_mixin.get_crf_status_default,
                        help_text="If some data is still pending, flag this CRF as incomplete",
                        max_length=25,
                        verbose_name="CRF status",
                    ),
                ),
                (
                    "crf_status_comments",
                    models.TextField(
                        blank=True,
                        help_text="for example, why some data is still pending",
                        null=True,
                        verbose_name="Any comments related to status of this CRF",
                    ),
                ),
                ("dx_date", models.DateField(verbose_name="Date of diagnosis")),
                (
                    "dx_initiated_by",
                    models.CharField(
                        choices=[
                            ("fbg", "Any FBG >= 7.0 mmol/L"),
                            ("ogtt", "Annual OGTT >= 11.1 mmol/L"),
                            ("OTHER", "Other"),
                        ],
                        max_length=25,
                        verbose_name="What initiated the diagnosis",
                    ),
                ),
                (
                    "dx_tmg",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=15,
                        verbose_name="Was the diagnosis discussed with the TMG?",
                    ),
                ),
                ("dx_tmg_date", models.DateField(verbose_name="Date of TMG discussion")),
                ("comments", models.TextField(verbose_name="Any other comments")),
                (
                    "site",
                    models.ForeignKey(
                        null=True,
                        on_delete=django.db.models.deletion.PROTECT,
                        related_name="+",
                        to="sites.site",
                    ),
                ),
                (
                    "subject_visit",
                    models.OneToOneField(
                        on_delete=django.db.models.deletion.PROTECT,
                        to="meta_subject.subjectvisit",
                    ),
                ),
            ],
            options={
                "verbose_name": "Diabetes diagnosis",
                "verbose_name_plural": "Diabetes diagnosis",
                "abstract": False,
                "default_permissions": ("add", "change", "delete", "view", "export", "import"),
                "default_manager_name": "objects",
            },
            managers=[
                ("objects", edc_visit_tracking.managers.CrfModelManager()),
                ("on_site", edc_visit_tracking.managers.CrfCurrentSiteManager()),
            ],
        ),
        migrations.CreateModel(
            name="HistoricalDmDiagnosis",
            fields=[
                (
                    "revision",
                    django_revision.revision_field.RevisionField(
                        blank=True,
                        editable=False,
                        help_text="System field. Git repository tag:branch:commit.",
                        max_length=75,
                        null=True,
                        verbose_name="Revision",
                    ),
                ),
                (
                    "created",
                    models.DateTimeField(blank=True, default=django.utils.timezone.now),
                ),
                (
                    "modified",
                    models.DateTimeField(blank=True, default=django.utils.timezone.now),
                ),
                (
                    "user_created",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user created",
                    ),
                ),
                (
                    "user_modified",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user modified",
                    ),
                ),
                (
                    "hostname_created",
                    models.CharField(
                        blank=True,
                        default=_socket.gethostname,
                        help_text="System field. (modified on create only)",
                        max_length=60,
                        verbose_name="Hostname created",
                    ),
                ),
                (
                    "hostname_modified",
                    django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                        blank=True,
                        help_text="System field. (modified on every save)",
                        max_length=50,
                        verbose_name="Hostname modified",
                    ),
                ),
                (
                    "device_created",
                    models.CharField(blank=True, max_length=10, verbose_name="Device created"),
                ),
                (
                    "device_modified",
                    models.CharField(
                        blank=True, max_length=10, verbose_name="Device modified"
                    ),
                ),
                (
                    "locale_created",
                    models.CharField(
                        blank=True,
                        help_text="Auto-updated by Modeladmin",
                        max_length=10,
                        null=True,
                        verbose_name="Locale created",
                    ),
                ),
                (
                    "locale_modified",
                    models.CharField(
                        blank=True,
                        help_text="Auto-updated by Modeladmin",
                        max_length=10,
                        null=True,
                        verbose_name="Locale modified",
                    ),
                ),
                (
                    "id",
                    django_audit_fields.fields.uuid_auto_field.UUIDAutoField(
                        blank=True,
                        db_index=True,
                        editable=False,
                        help_text="System auto field. UUID primary key.",
                    ),
                ),
                ("consent_model", models.CharField(blank=True, max_length=50, null=True)),
                ("consent_version", models.CharField(blank=True, max_length=10, null=True)),
                (
                    "report_datetime",
                    models.DateTimeField(
                        default=edc_utils.date.get_utcnow,
                        help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.",
                        validators=[
                            edc_protocol.validators.datetime_not_before_study_start,
                            edc_model.validators.date.datetime_not_future,
                        ],
                        verbose_name="Report Date",
                    ),
                ),
                (
                    "crf_status",
                    models.CharField(
                        choices=[
                            ("INCOMPLETE", "Incomplete (some data pending)"),
                            ("COMPLETE", "Complete"),
                        ],
                        default=edc_crf.model_mixins.crf_status_model_mixin.get_crf_status_default,
                        help_text="If some data is still pending, flag this CRF as incomplete",
                        max_length=25,
                        verbose_name="CRF status",
                    ),
                ),
                (
                    "crf_status_comments",
                    models.TextField(
                        blank=True,
                        help_text="for example, why some data is still pending",
                        null=True,
                        verbose_name="Any comments related to status of this CRF",
                    ),
                ),
                ("dx_date", models.DateField(verbose_name="Date of diagnosis")),
                (
                    "dx_initiated_by",
                    models.CharField(
                        choices=[
                            ("fbg", "Any FBG >= 7.0 mmol/L"),
                            ("ogtt", "Annual OGTT >= 11.1 mmol/L"),
                            ("OTHER", "Other"),
                        ],
                        max_length=25,
                        verbose_name="What initiated the diagnosis",
                    ),
                ),
                (
                    "dx_tmg",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=15,
                        verbose_name="Was the diagnosis discussed with the TMG?",
                    ),
                ),
                ("dx_tmg_date", models.DateField(verbose_name="Date of TMG discussion")),
                ("comments", models.TextField(verbose_name="Any other comments")),
                (
                    "history_id",
                    models.UUIDField(
                        default=uuid.uuid4, editable=False, primary_key=True, serialize=False
                    ),
                ),
                ("history_date", models.DateTimeField(db_index=True)),
                ("history_change_reason", models.CharField(max_length=100, null=True)),
                (
                    "history_type",
                    models.CharField(
                        choices=[("+", "Created"), ("~", "Changed"), ("-", "Deleted")],
                        max_length=1,
                    ),
                ),
                (
                    "history_user",
                    models.ForeignKey(
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        related_name="+",
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
                (
                    "site",
                    models.ForeignKey(
                        blank=True,
                        db_constraint=False,
                        null=True,
                        on_delete=django.db.models.deletion.DO_NOTHING,
                        related_name="+",
                        to="sites.site",
                    ),
                ),
                (
                    "subject_visit",
                    models.ForeignKey(
                        blank=True,
                        db_constraint=False,
                        null=True,
                        on_delete=django.db.models.deletion.DO_NOTHING,
                        related_name="+",
                        to="meta_subject.subjectvisit",
                    ),
                ),
            ],
            options={
                "verbose_name": "historical Diabetes diagnosis",
                "verbose_name_plural": "historical Diabetes diagnosis",
                "ordering": ("-history_date", "-history_id"),
                "get_latest_by": ("history_date", "history_id"),
            },
            bases=(simple_history.models.HistoricalChanges, models.Model),
        ),
        migrations.AddIndex(
            model_name="dmdiagnosis",
            index=models.Index(
                fields=["subject_visit", "site"], name="meta_subjec_subject_40b1c1_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="dmdiagnosis",
            index=models.Index(
                fields=["subject_visit", "report_datetime"],
                name="meta_subjec_subject_2059c2_idx",
            ),
        ),
    ]



# Generated by Django 2.2.6 on 2019-10-20 04:38

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [("meta_screening", "0003_auto_20191020_0627")]

    operations = [
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="creatinine",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                max_digits=8,
                null=True,
                verbose_name="Serum creatinine levels",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="fasting_glucose",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                help_text="in mmol/L",
                max_digits=8,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(50),
                ],
                verbose_name="Fasting glucose levels",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="hba1c",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                help_text="in %",
                max_digits=8,
                null=True,
                verbose_name="HbA1c",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="ogtt_two_hr",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                help_text="in mmol/L",
                max_digits=8,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(300),
                ],
                verbose_name="Blood glucose levels 2-hours after glucose solution given",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="ogtt_two_hr_units",
            field=models.CharField(
                blank=True,
                choices=[("mg/dL", "mg/dL"), ("mmol/L", "mmol/L")],
                default="mmol/L",
                editable=False,
                max_length=15,
                verbose_name="Units (Blood glucose)",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="weight",
            field=models.DecimalField(
                decimal_places=2,
                help_text="in kgs",
                max_digits=8,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(15),
                    django.core.validators.MaxValueValidator(135),
                ],
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="creatinine",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                max_digits=8,
                null=True,
                verbose_name="Serum creatinine levels",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="fasting_glucose",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                help_text="in mmol/L",
                max_digits=8,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(50),
                ],
                verbose_name="Fasting glucose levels",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="hba1c",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                help_text="in %",
                max_digits=8,
                null=True,
                verbose_name="HbA1c",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="ogtt_two_hr",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                help_text="in mmol/L",
                max_digits=8,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(300),
                ],
                verbose_name="Blood glucose levels 2-hours after glucose solution given",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="ogtt_two_hr_units",
            field=models.CharField(
                blank=True,
                choices=[("mg/dL", "mg/dL"), ("mmol/L", "mmol/L")],
                default="mmol/L",
                editable=False,
                max_length=15,
                verbose_name="Units (Blood glucose)",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="weight",
            field=models.DecimalField(
                decimal_places=2,
                help_text="in kgs",
                max_digits=8,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(15),
                    django.core.validators.MaxValueValidator(135),
                ],
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="creatinine",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                max_digits=8,
                null=True,
                verbose_name="Serum creatinine levels",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="fasting_glucose",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                help_text="in mmol/L",
                max_digits=8,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(50),
                ],
                verbose_name="Fasting glucose levels",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="hba1c",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                help_text="in %",
                max_digits=8,
                null=True,
                verbose_name="HbA1c",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="ogtt_two_hr",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                help_text="in mmol/L",
                max_digits=8,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(300),
                ],
                verbose_name="Blood glucose levels 2-hours after glucose solution given",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="ogtt_two_hr_units",
            field=models.CharField(
                blank=True,
                choices=[("mg/dL", "mg/dL"), ("mmol/L", "mmol/L")],
                default="mmol/L",
                editable=False,
                max_length=15,
                verbose_name="Units (Blood glucose)",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="weight",
            field=models.DecimalField(
                decimal_places=2,
                help_text="in kgs",
                max_digits=8,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(15),
                    django.core.validators.MaxValueValidator(135),
                ],
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="creatinine",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                max_digits=8,
                null=True,
                verbose_name="Serum creatinine levels",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="fasting_glucose",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                help_text="in mmol/L",
                max_digits=8,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(50),
                ],
                verbose_name="Fasting glucose levels",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="hba1c",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                help_text="in %",
                max_digits=8,
                null=True,
                verbose_name="HbA1c",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="ogtt_two_hr",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                help_text="in mmol/L",
                max_digits=8,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(300),
                ],
                verbose_name="Blood glucose levels 2-hours after glucose solution given",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="ogtt_two_hr_units",
            field=models.CharField(
                blank=True,
                choices=[("mg/dL", "mg/dL"), ("mmol/L", "mmol/L")],
                default="mmol/L",
                editable=False,
                max_length=15,
                verbose_name="Units (Blood glucose)",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="weight",
            field=models.DecimalField(
                decimal_places=2,
                help_text="in kgs",
                max_digits=8,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(15),
                    django.core.validators.MaxValueValidator(135),
                ],
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="creatinine",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                max_digits=8,
                null=True,
                verbose_name="Serum creatinine levels",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="fasting_glucose",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                help_text="in mmol/L",
                max_digits=8,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(50),
                ],
                verbose_name="Fasting glucose levels",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="hba1c",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                help_text="in %",
                max_digits=8,
                null=True,
                verbose_name="HbA1c",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="ogtt_two_hr",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                help_text="in mmol/L",
                max_digits=8,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(300),
                ],
                verbose_name="Blood glucose levels 2-hours after glucose solution given",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="ogtt_two_hr_units",
            field=models.CharField(
                blank=True,
                choices=[("mg/dL", "mg/dL"), ("mmol/L", "mmol/L")],
                default="mmol/L",
                editable=False,
                max_length=15,
                verbose_name="Units (Blood glucose)",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="weight",
            field=models.DecimalField(
                decimal_places=2,
                help_text="in kgs",
                max_digits=8,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(15),
                    django.core.validators.MaxValueValidator(135),
                ],
            ),
        ),
    ]



from __future__ import annotations

from clinicedc_constants import NOT_APPLICABLE
from django.contrib import admin
from django.contrib.admin import SimpleListFilter
from django.template.loader import render_to_string
from django_audit_fields.admin import audit_fieldset_tuple
from edc_crf.fieldset import crf_status_fieldset
from edc_model_admin.history import SimpleHistoryAdmin

from meta_lists.constants import HEMACUE
from meta_lists.models import DiagnosticDevices

from ..admin_site import meta_subject_admin
from ..forms import GlucoseForm
from ..models import Glucose
from .list_filters import FbgListFilter, OgttListFilter
from .modeladmin import CrfModelAdminMixin


@admin.register(Glucose, site=meta_subject_admin)
class GlucoseAdmin(CrfModelAdminMixin, SimpleHistoryAdmin):
    form = GlucoseForm

    fieldsets = (
        (None, {"fields": ("subject_visit", "report_datetime")}),
        (
            "Fasting",
            {
                "fields": (
                    "fasting",
                    "fasting_duration_str",
                )
            },
        ),
        (
            "Blood Glucose",
            {
                "fields": (
                    "fbg_performed",
                    "fbg_not_performed_reason",
                    "fbg_datetime",
                    "fbg_diagnostic_device",
                    "fbg_value",
                    "fbg_units",
                )
            },
        ),
        (
            "OGTT",
            {
                "fields": (
                    "ogtt_performed",
                    "ogtt_not_performed_reason",
                    "ogtt_base_datetime",
                    "ogtt_datetime",
                    "ogtt_diagnostic_device",
                    "ogtt_value",
                    "ogtt_units",
                )
            },
        ),
        (
            "Endpoint review",
            {
                "description": render_to_string(
                    "meta_subject/endpoint_review_instructions.html", context={}
                ),
                "fields": (
                    "endpoint_today",
                    "repeat_fbg_date",
                ),
            },
        ),
        crf_status_fieldset,
        audit_fieldset_tuple,
    )

    radio_fields = {  # noqa: RUF012
        "fasting": admin.VERTICAL,
        "fbg_units": admin.VERTICAL,
        "fbg_performed": admin.VERTICAL,
        "ogtt_performed": admin.VERTICAL,
        "ogtt_units": admin.VERTICAL,
        "endpoint_today": admin.VERTICAL,
        "fbg_diagnostic_device": admin.VERTICAL,
        "ogtt_diagnostic_device": admin.VERTICAL,
    }

    def get_list_display(self, request) -> tuple[str, ...]:
        list_display = super().get_list_display(request)
        list_display = list(list_display)
        list_display.insert(3, "ogtt_dx_device")
        list_display.insert(3, "fbg_dx_device")
        list_display.insert(3, "ogtt")
        list_display.insert(3, "fbg_value")
        list_display = [f for f in list_display if f != "__str__"]
        return tuple(list_display)

    def get_list_filter(self, request) -> tuple[str | type[SimpleListFilter], ...]:
        list_filter = super().get_list_filter(request)
        list_filter = list(list_filter)
        list_filter.insert(2, "fbg_diagnostic_device")
        list_filter.insert(2, "ogtt_diagnostic_device")
        list_filter.insert(2, OgttListFilter)
        list_filter.insert(2, FbgListFilter)
        return tuple(list_filter)

    @admin.display(description="FBG", ordering="fbg_value")
    def fbg(self, obj):
        return obj.fbg_value

    @admin.display(description="OGTT", ordering="ogtt_value")
    def ogtt(self, obj):
        return obj.ogtt_value

    def get_changeform_initial_data(self, request) -> dict:
        initial_data = super().get_changeform_initial_data(request)
        try:
            obj = DiagnosticDevices.objects.get(name=HEMACUE)
        except DiagnosticDevices.DoesNotExist:
            pass
        else:
            initial_data["fbg_diagnostic_device"] = obj.id
        try:
            obj = DiagnosticDevices.objects.get(name=NOT_APPLICABLE)
        except DiagnosticDevices.DoesNotExist:
            pass
        else:
            initial_data["ogtt_diagnostic_device"] = obj.id
        return initial_data

    @admin.display(description="FBG Device", ordering="fbg_diagnostic_device")
    def fbg_dx_device(self, obj=None):
        if obj:
            return obj.fbg_diagnostic_device
        return None

    @admin.display(description="OGTT Device", ordering="ogtt_diagnostic_device")
    def ogtt_dx_device(self, obj=None):
        if obj:
            return obj.fbg_diagnostic_device
        return None



# Generated by Django 5.1.2 on 2025-01-11 00:44

from django.db import IntegrityError, migrations, transaction
from edc_registration.models import RegisteredSubject
from tqdm import tqdm

from meta_consent.action_items import ConsentV1ExtensionAction


def update_action_item(apps, schema_editor):
    total = RegisteredSubject.objects.all().count()
    for obj in tqdm(RegisteredSubject.objects.all(), total=total):
        try:
            with transaction.atomic():
                ConsentV1ExtensionAction(
                    subject_identifier=obj.subject_identifier,
                    skip_get_current_site=True,
                    site_id=obj.site_id,
                )
        except IntegrityError:
            pass


class Migration(migrations.Migration):

    dependencies = [
        ("meta_consent", "0026_historicalsubjectconsentv1ext_subjectconsentv1ext"),
    ]

    operations = [migrations.RunPython(update_action_item)]



# Generated by Django 3.0.4 on 2020-04-22 17:39

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("meta_subject", "0030_auto_20200420_1816"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="coronakap",
            name="shared_housing_one",
        ),
        migrations.RemoveField(
            model_name="coronakap",
            name="shared_housing_two",
        ),
        migrations.RemoveField(
            model_name="historicalcoronakap",
            name="shared_housing_one",
        ),
        migrations.RemoveField(
            model_name="historicalcoronakap",
            name="shared_housing_two",
        ),
        migrations.AddField(
            model_name="coronakap",
            name="diabetic_missed_doses",
            field=models.IntegerField(
                blank=True,
                null=True,
                verbose_name="If 'Yes', in the last month <u>how many days</u> did you miss taking your <u>diabetes</u> medications?",
            ),
        ),
        migrations.AddField(
            model_name="coronakap",
            name="hiv_missed_doses",
            field=models.IntegerField(
                blank=True,
                null=True,
                verbose_name="If 'Yes', in the last month <u>how many days</u> did you miss taking your <u>ART</u> medications?",
            ),
        ),
        migrations.AddField(
            model_name="coronakap",
            name="household_size",
            field=models.IntegerField(
                default=2,
                help_text="Family / people who spend more than 14 nights per month in your home.",
                verbose_name="How many people live together in your home / dwelling?",
            ),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="coronakap",
            name="hypertensive_missed_doses",
            field=models.IntegerField(
                blank=True,
                null=True,
                verbose_name="If 'Yes', in the last month <u>how many days</u> did you miss taking your <u>hypertension</u> medications?",
            ),
        ),
        migrations.AddField(
            model_name="coronakap",
            name="nights_away",
            field=models.IntegerField(
                default=0,
                help_text="e.g. travelling for work, staying with family",
                verbose_name="In the last one month, how many nights did you spend away from your home / dwelling?",
            ),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="historicalcoronakap",
            name="diabetic_missed_doses",
            field=models.IntegerField(
                blank=True,
                null=True,
                verbose_name="If 'Yes', in the last month <u>how many days</u> did you miss taking your <u>diabetes</u> medications?",
            ),
        ),
        migrations.AddField(
            model_name="historicalcoronakap",
            name="hiv_missed_doses",
            field=models.IntegerField(
                blank=True,
                null=True,
                verbose_name="If 'Yes', in the last month <u>how many days</u> did you miss taking your <u>ART</u> medications?",
            ),
        ),
        migrations.AddField(
            model_name="historicalcoronakap",
            name="household_size",
            field=models.IntegerField(
                default=0,
                help_text="Family / people who spend more than 14 nights per month in your home.",
                verbose_name="How many people live together in your home / dwelling?",
            ),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="historicalcoronakap",
            name="hypertensive_missed_doses",
            field=models.IntegerField(
                blank=True,
                null=True,
                verbose_name="If 'Yes', in the last month <u>how many days</u> did you miss taking your <u>hypertension</u> medications?",
            ),
        ),
        migrations.AddField(
            model_name="historicalcoronakap",
            name="nights_away",
            field=models.IntegerField(
                default=0,
                help_text="e.g. travelling for work, staying with family",
                verbose_name="In the last one month, how many nights did you spend away from your home / dwelling?",
            ),
            preserve_default=False,
        ),
    ]
